diff code_part1/OSTC_code_asm_part1/menu_reset.asm @ 9:395230c28023

Added CF36: Divemask color
author heinrichsweikamp
date Tue, 09 Mar 2010 13:06:26 +0100
parents 3cf8af30b36e
children b7ace8994b29
line wrap: on
line diff
--- a/code_part1/OSTC_code_asm_part1/menu_reset.asm	Sun Feb 28 16:19:21 2010 +0100
+++ b/code_part1/OSTC_code_asm_part1/menu_reset.asm	Tue Mar 09 13:06:26 2010 +0100
@@ -251,9 +251,9 @@
 
 #DEFINE	GF_low_default				d'30'		; 8Bit		30%
 #DEFINE	GF_high_default				d'90'		; 8Bit		90%
 #DEFINE	color_battery_surface		d'223'		; 8Bit		Color Battery sign Surfacemode
 #DEFINE	color_standard1				d'255'		; 8Bit		1.40Bar
 #DEFINE	SP_nom_HUD_default			d'120'		; 8Bit		1.20Bar
 #DEFINE	HUD_style					d'0'		; 8Bit		OSTC Style
 
 #DEFINE	show_seconds_divemode		d'0'		; 1Bit 		=1 Show the seconds in Divemode
@@ -387,7 +387,7 @@
 	movlw	color_standard1
 	rcall	reset_customfunction	; saves default and current value
 
-	movlw	SP_nom_HUD_default			
+	movlw	color_divemask
 	rcall	reset_customfunction	; saves default and current value
 
 	movlw	HUD_style
@@ -251,9 +251,9 @@
 #DEFINE	GF_low_default				d'30'		; 8Bit		30%
 #DEFINE	GF_high_default				d'90'		; 8Bit		90%
-#DEFINE	color_battery_surface		d'223'		; 8Bit		Color Battery sign Surfacemode
-#DEFINE	color_standard1				d'255'		; 8Bit		1.40Bar
-#DEFINE	SP_nom_HUD_default			d'120'		; 8Bit		1.20Bar
+#DEFINE	color_battery_surface		d'223'		; 8Bit		Color Battery sign: Cyan
+#DEFINE	color_standard1				d'255'		; 8Bit		Color Standard: White
+#DEFINE	color_divemask				d'224'		; 8Bit		Color Divemask: Red
 #DEFINE	HUD_style					d'0'		; 8Bit		OSTC Style
 